UpdateThingShadowResponse class

The output from the UpdateThingShadow operation.

Constructors

UpdateThingShadowResponse({Uint8List? payload})

Properties

hashCode → int
The hash code for this object.
no setterinherited
payload → Uint8List?
The state information, in JSON format.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited